@@ -43,7 +43,9 @@ class parseDataset(object):
             
         self.out_channel = out_channel
         
-    def read(self, batch_size = 128, shuffle = True, mode = 'default'):
+    def read(self, batch_size = 128, shuffle = True, mode = 'default', task='system', one_hot= False):
+        self.task = task
+        self.one_hot = one_hot
         if self.ext == 'hdf5':
             ds = self.prepare_dataset_from_hdf5(batch_size , shuffle , mode)
         elif self.ext == 'tfrecords':
@@ -255,11 +257,38 @@ class parseDataset(object):
         group = example_message['group']
         system = example_message['system']
         
-        return (self._replace_nan(pot), group, system)
+        #TODO: Onehot encoding tasks
+        if self.task == 'system':
+            if self.one_hot:
+                return (self._replace_nan(pot), self._one_hot(system, 7))
+            else:
+                return (self._replace_nan(pot), tf.cast(system, tf.int64))
+        elif self.task == 'space group':
+            return (self._replace_nan(pot), tf.cast(group, tf.int64))
+        else:
+            raise Exception('classification task type implemented')
+        
     
     def _replace_nan(self,tensor):
         return tf.where(tf.math.is_nan(tensor), tf.zeros_like(tensor), tensor)
-
+    
+    def _one_hot(self,y, num_classes):
+        label_dict = [0,1,2,3,4,5,6]
+        if tf.equal(np.int64(0),y):
+            return tf.one_hot(label_dict[0],num_classes,dtype=tf.int64)
+        elif tf.equal(np.int64(1),y):
+            return tf.one_hot(label_dict[1],num_classes,dtype=tf.int64)
+        elif tf.equal(np.int64(2),y):
+            return tf.one_hot(label_dict[2],num_classes,dtype=tf.int64)
+        elif tf.equal(np.int64(3),y):
+            return tf.one_hot(label_dict[3],num_classes,dtype=tf.int64)
+        elif tf.equal(np.int64(4),y):
+            return tf.one_hot(label_dict[4],num_classes,dtype=tf.int64)
+        elif tf.equal(np.int64(5),y):
+            return tf.one_hot(label_dict[5],num_classes,dtype=tf.int64)
+        else:
+            return tf.one_hot(label_dict[6],num_classes,dtype=tf.int64)
+        
 
 '''
 =====================================================================================================================================
